@@ -23,7 +23,7 @@ require 'spec_helper'
 describe 'neutron::services::fwaas' do
   let :pre_condition do
     "class { 'neutron': }
-     include ::neutron::agents::l3"
+     include neutron::agents::l3"
   end
 
   let :params do
@@ -66,7 +66,7 @@ describe 'neutron::services::fwaas' do
       should contain_package('neutron-fwaas').with(
         :ensure => 'present',
         :tag    => ['neutron-package', 'openstack'],
-        :name   => 'python-neutron-fwaas',
+        :name   => platform_params[:fwaas_package_name],
       )
     end
   end
@@ -77,7 +77,7 @@ describe 'neutron::services::fwaas' do
         should contain_package('neutron-fwaas').with(
           :ensure => 'present',
           :tag    => ['neutron-package', 'openstack'],
-          :name   => 'python-neutron-fwaas',
+          :name   => platform_params[:fwaas_package_name],
         )
       end
     end
@@ -90,6 +90,7 @@ describe 'neutron::services::fwaas' do
       it 'installs neutron vpnaas agent package' do
         should contain_package('neutron-vpn-agent').with(
           :ensure => 'present',
+          :name   => platform_params[:vpnaas_package_name],
           :tag    => ['neutron-package', 'openstack'],
         )
       end
@@ -100,7 +101,7 @@ describe 'neutron::services::fwaas' do
     it 'installs neutron fwaas service package' do
       should contain_package('neutron-fwaas').with(
         :ensure => 'present',
-        :name   => 'openstack-neutron-fwaas',
+        :name   => platform_params[:fwaas_package_name],
       )
     end
   end
@@ -114,7 +115,17 @@ describe 'neutron::services::fwaas' do
       end
 
       let (:platform_params) do
-        {}
+        case facts[:osfamily]
+        when 'Debian'
+          { 
+            :fwaas_package_name   => 'python3-neutron-fwaas',
+            :vpnaas_package_name  => 'python-neutron-vpnaas'
+          }
+        when 'RedHat'
+          {
+            :fwaas_package_name => 'openstack-neutron-fwaas'
+          }
+        end
       end
 
       it_behaves_like 'neutron fwaas service plugin'
